#### Brief description:

- Query the latest photo taken by a vehicle.

#### API version:

| Version | Author | Creation Date | Revision Date |
| :------ | :----- | :------------ | :------------ |
| 2.0.0   | Lenny  | 2024-01-24    |               |

#### Request URL:

- International clients: http://icloud.assetscontrols.com:8092/OpenApi/Instruction
- Domestic clients: http://cloud.assetscontrols.com:8092/OpenApi/Instruction

#### Request Method:

- POST

#### Request Headers:

| Parameter    | Required | Type   | Description                    |
| :----------- | :------- | :----- | :----------------------------- |
| Content-Type | Yes      | string | Request type: application/json |

#### Request Parameters:

| Parameter    | Required | Type   | Description                                             |
| :----------- | :------- | :----- | ------------------------------------------------------- |
| FTokenID     | Yes      | string | Token ID                                                |
| FAction      | Yes      | string | Method name (QueryCameraImgsList)                       |
| FVehicleGUID | Yes      | string | Vehicle GUID, e.g. 3C611B54-623E-6FA8-3924-791C9CC94323 |
| FStartTime   | Yes      | string | Start time                                              |
| FEndTime     | Yes      | String | End time                                                |
| FVersion     | Yes      | String | Version number                                          |

#### Response Example:

**When successful:**

```
{
	"Result": 200,
	"Message": "check token success",
	"FObject": [
		{
			"FVehicleGUID": "a4b40424-cfc4-4b78-84ed-6fbb0b7f28d2",
			"FVehicleName": "876208000137",
			"FAssetGuid": "a64b2e58-9305-4a01-9c51-092205123945",
			"FAssetID": "876208000137",
			"FAssetTypeID": 3705,
			"FCameraID": 1,
			"FType": 0,
			"FDateTime": "2024/1/24 6:17:21",
			"FLongitude": "0",
			"FLatitude": "0",
			"FReasonKey": 0,
			"FUrl": "http://jointech-705c-bucket.obs.ap-southeast-1.myhuaweicloud.com/OBS_LockFiles/876208000137_1706105841/876208000137_1706105841_08_00.jpeg"
		}
	]
}
```

**When there's an error:**

```
{
    "Result": 102,
    "Message": "Action is error",
    "FObject": []
}
```

#### Response Parameters:

| Parameter            | Type     | Description                                                  |
| -------------------- | -------- | ------------------------------------------------------------ |
| FVehicleGUID         | String   | Vehicle ID                                                   |
| FVehicleName         | String   | License plate number                                         |
| FAssetID             | String   | Terminal ID                                                  |
| FAssetTypeID         | String   | Terminal type                                                |
| FCameraID            | String   | Camera ID                                                    |
| FGpsTime             | DateTime | Capture time                                                 |
| FLongitude           | Double   | Capture longitude                                            |
| FLatitude            | Double   | Capture latitude                                             |
| FShortName           | String   | Company abbreviation                                         |
| FReasonKey           | String   | Capture reason, 1 for timed capture, 2 for triggered capture, 3 for immediate capture |
| FUrl                 | String   | Image URL                                                    |
| FCustomAssetTypeName | String   | Custom device type name                                      |

#### Note:

- Additional error codes include:
- 105: System exception
- 102: Parameter error

#### Examples:


**Java:**
```
String result = "";
String url = "http://cloud.assetscontrols.com:8092/OpenApi/Instruction";  
String body = "{\"FAction\":\"QueryCameraImgsList\",\"FVehicleGUID\":\"a4b40424-cfc4-4b78-84ed-6fbb0b7f28d2\",\"FStartTime\":\"2024-01-23 16:00:00\",\"FEndTime\":\"2024-01-24 15:59:59\",\"FTokenID\":\"3acef045-d302-4032-b40a-d9ee6c1519cd\",\"FTimeDifferent\":28800,\"FLanguage\":\"1\"}";  
URL realUrl = new URL(url);
URLConnection conn = realUrl.openConnection(); 
conn.setRequestProperty("accept", "*/*");
conn.setRequestProperty("connection", "keep-Alive");
conn.setRequestProperty("Content-Type", "application/json");
conn.setRequestProperty("user-agent", "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1;SV1)");
conn.setRequestProperty("method", "post");
conn.setDoOutput(true);
conn.setDoInput(true);
PrintWriter pw = new PrintWriter(conn.getOutputStream());
pw.print(body);
pw.flush();   
BufferedReader bufReader = new BufferedReader(new InputStreamReader(conn.getInputStream()));  
String line;
while ((line = bufReader.readLine()) != null) {
     result += line;        
 }
return result;
```

**C#：**
```
string url = "http://cloud.assetscontrols.com:8092/OpenApi/Instruction";  
string body = "{\"FAction\":\"QueryCameraImgsList\",\"FVehicleGUID\":\"a4b40424-cfc4-4b78-84ed-6fbb0b7f28d2\",\"FStartTime\":\"2024-01-23 16:00:00\",\"FEndTime\":\"2024-01-24 15:59:59\",\"FTokenID\":\"3acef045-d302-4032-b40a-d9ee6c1519cd\",\"FTimeDifferent\":28800,\"FLanguage\":\"1\"}"; 
Encoding encoding = Encoding.UTF8;
HttpWebRequest request = (HttpWebRequest)WebRequest.Create(url);
request.Method = "post"; 
request.Accept = "*/*";    
request.ContentType = "application/json";
request.UserAgent = "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)";
byte[] buffer = encoding.GetBytes(body);
request.ContentLength = buffer.Length;
request.GetRequestStream().Write(buffer, 0, buffer.Length);
HttpWebResponse response = (HttpWebResponse)request.GetResponse();
using (StreamReader reader = new StreamReader(response.GetResponseStream(), Encoding.UTF8))
{
    return reader.ReadToEnd();
}
```

**Python：**
```python
url = "http://cloud.assetscontrols.com:8092/OpenApi/Instruction"
payload = {
    "FAction": "QueryCameraImgsList",
    "FVehicleGUID": "a4b40424-cfc4-4b78-84ed-6fbb0b7f28d2",
    "FStartTime": "2024-01-23 16:00:00",
    "FEndTime": "2024-01-24 15:59:59",
    "FTokenID": "3acef045-d302-4032-b40a-d9ee6c1519cd",
    "FTimeDifferent": 28800,
    "FLanguage": "1"
}
headers = {
    "Authorization": "eyJhbGciOiJIUzUxMiJ9.eyJsb2dpbl91c2VyX2tleSI6IjZjNTg4Yjk2LTkyNTQtNDcyMC1iYzMwLWQ0ZTI0Mzc4YzMyMCJ9.oTjYmJFpmPDSqFX8oHkzdBMYhidGWxDaeygdKY3SphFrxq3yRzyPOq80kFUW1CH-gVW8M6tRlzTrPkvANMQxMg",
    "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:121.0) Gecko/20100101 Firefox/121.0",
    "Accept": "application/json, text/plain, */*",
    "Accept-Language": "zh-CN,zh;q=0.8,zh-TW;q=0.7,zh-HK;q=0.5,en-US;q=0.3,en;q=0.2",
    "Accept-Encoding": "gzip, deflate",
    "Content-Type": "application/json",
    "Origin": "http://120.25.245.20:8081",
    "Connection": "keep-alive",
    "Referer": "http://120.25.245.20:8081/",
    "content-type": "application/json"
}

response = requests.request("POST", url, json=payload, headers=headers)

print(response.text)
```

**Node.js:**
``` 

const request = require('request');

const options = {
  method: 'POST',
 url = 'http://cloud.assetscontrols.com:8092/OpenApi/Instruction',
  headers: {
    Authorization: 'eyJhbGciOiJIUzUxMiJ9.eyJsb2dpbl91c2VyX2tleSI6IjZjNTg4Yjk2LTkyNTQtNDcyMC1iYzMwLWQ0ZTI0Mzc4YzMyMCJ9.oTjYmJFpmPDSqFX8oHkzdBMYhidGWxDaeygdKY3SphFrxq3yRzyPOq80kFUW1CH-gVW8M6tRlzTrPkvANMQxMg',
    'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:121.0) Gecko/20100101 Firefox/121.0',
    Accept: 'application/json, text/plain, */*',
    'Accept-Language': 'zh-CN,zh;q=0.8,zh-TW;q=0.7,zh-HK;q=0.5,en-US;q=0.3,en;q=0.2',
    'Accept-Encoding': 'gzip, deflate',
    'Content-Type': 'application/json',
    Origin: 'http://120.25.245.20:8081',
    Connection: 'keep-alive',
    Referer: 'http://120.25.245.20:8081/',
    'content-type': 'application/json'
  },
  body: {
    FAction: 'QueryCameraImgsList',
    FVehicleGUID: 'a4b40424-cfc4-4b78-84ed-6fbb0b7f28d2',
    FStartTime: '2024-01-23 16:00:00',
    FEndTime: '2024-01-24 15:59:59',
    FTokenID: '3acef045-d302-4032-b40a-d9ee6c1519cd',
    FTimeDifferent: 28800,
    FLanguage: '1'
  },
  json: true
};

request(options, function (error, response, body) {
  if (error) throw new Error(error);

  console.log(body);
});

```