#### Brief Description:

- Active Photograph (including GP and Su standard)

#### API Version:

| Version | Created by | Created Date | Revised Date |
| :------ | :--------- | :----------- | :----------- |
| 2.0.0   | lenny      | 2024-01-24   |              |

#### Request URL:

- International Client: http://icloud.assetscontrols.com:8092/OpenApi/Instruction
- Domestic Client: http://cloud.assetscontrols.com:8092/OpenApi/Instruction

#### Request Method:

- POST

#### Request Header:

| Parameter    | Required | Type   | Description                    |
| :----------- | :------- | :----- | ------------------------------ |
| Content-Type | Yes      | string | Request type: application/json |

#### Request Parameters:

| Parameter             | Required | Type   | Description                    |
| :-------------------- | :------- | :----- | ------------------------------ |
| FTokenID              | Yes      | string | Token ID                       |
| FAction               | Yes      | string | Method name (ActivePhotograph) |
| FVehicleGUID          | Yes      | string | Terminal unique identifier     |
| FT_GpActivePhotograph | Yes      | Object |                                |

**FT_GpActivePhotograph**

| Parameter | Required | Type   | Description                                                  |
| :-------- | :------- | :----- | ------------------------------------------------------------ |
| FCameraID | Yes      | String | Camera ID                                                    |
| FInterval | Yes      | int    | Image transmission interval in seconds, maximum value is 3600 seconds, minimum value is 10 seconds. |
| FCount    | Yes      | int    | Number of images to be transmitted. If set to 0, no more image data will be uploaded. Maximum value is 100. |

#### Response Example:

**When successful:**

```
{
	"Result": 200,
	"Message": "ins send ok",
	"FObject": []
}
```

**When there's an error:**

```
{
    "Result": 102,
    "Message": "Action is error",
    "FObject": []
}
```

#### Response Parameters:

None

#### Note:

- Additional error codes include:
- 105: System exception
- 108: Failed to send
- 102: Parameter error

#### Request Example:

**Java:**
```
String result = "";
String url = "http://cloud.assetscontrols.com:8092/OpenApi/Instruction";  
String body = "{\"FAction\":\"ActivePhotograph\",\"FAssetGUID\":\"a64b2e58-9305-4a01-9c51-092205123945\",\"FT_GpActivePhotograph\":{\"FAssetID\":\"876208000137\",\"FCount\":1},\"FTokenID\":\"3acef045-d302-4032-b40a-d9ee6c1519cd\",\"FTimeDifferent\":28800,\"FLanguage\":\"1\"}";  
URL realUrl = new URL(url);
URLConnection conn = realUrl.openConnection(); 
conn.setRequestProperty("accept", "*/*");
conn.setRequestProperty("connection", "keep-Alive");
conn.setRequestProperty("Content-Type", "application/json");
conn.setRequestProperty("user-agent", "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1;SV1)");
conn.setRequestProperty("method", "post");
conn.setDoOutput(true);
conn.setDoInput(true);
PrintWriter pw = new PrintWriter(conn.getOutputStream());
pw.print(body);
pw.flush();   
BufferedReader bufReader = new BufferedReader(new InputStreamReader(conn.getInputStream()));  
String line;
while ((line = bufReader.readLine()) != null) {
     result += line;        
 }
return result;
```

**C#：**
```
string url = "http://cloud.assetscontrols.com:8092/OpenApi/Instruction";  
string body = "{\"FAction\":\"ActivePhotograph\",\"FAssetGUID\":\"a64b2e58-9305-4a01-9c51-092205123945\",\"FT_GpActivePhotograph\":{\"FAssetID\":\"876208000137\",\"FCount\":1},\"FTokenID\":\"3acef045-d302-4032-b40a-d9ee6c1519cd\",\"FTimeDifferent\":28800,\"FLanguage\":\"1\"}"; 
Encoding encoding = Encoding.UTF8;
HttpWebRequest request = (HttpWebRequest)WebRequest.Create(url);
request.Method = "post"; 
request.Accept = "*/*";    
request.ContentType = "application/json";
request.UserAgent = "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)";
byte[] buffer = encoding.GetBytes(body);
request.ContentLength = buffer.Length;
request.GetRequestStream().Write(buffer, 0, buffer.Length);
HttpWebResponse response = (HttpWebResponse)request.GetResponse();
using (StreamReader reader = new StreamReader(response.GetResponseStream(), Encoding.UTF8))
{
    return reader.ReadToEnd();
}
```

**Python：**
```python
url = "http://cloud.assetscontrols.com:8092/OpenApi/Instruction"

payload = {
    "FAction": "ActivePhotograph",
    "FAssetGUID": "a64b2e58-9305-4a01-9c51-092205123945",
    "FT_GpActivePhotograph": {
        "FAssetID": "876208000137",
        "FCount": 1
    },
    "FTokenID": "3acef045-d302-4032-b40a-d9ee6c1519cd",
    "FTimeDifferent": 28800,
    "FLanguage": "1"
}
headers = {
    "Authorization": "eyJhbGciOiJIUzUxMiJ9.eyJsb2dpbl91c2VyX2tleSI6IjZjNTg4Yjk2LTkyNTQtNDcyMC1iYzMwLWQ0ZTI0Mzc4YzMyMCJ9.oTjYmJFpmPDSqFX8oHkzdBMYhidGWxDaeygdKY3SphFrxq3yRzyPOq80kFUW1CH-gVW8M6tRlzTrPkvANMQxMg",
    "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:121.0) Gecko/20100101 Firefox/121.0",
    "Accept": "application/json, text/plain, */*",
    "Accept-Language": "zh-CN,zh;q=0.8,zh-TW;q=0.7,zh-HK;q=0.5,en-US;q=0.3,en;q=0.2",
    "Accept-Encoding": "gzip, deflate",
    "Content-Type": "application/json",
    "Origin": "http://120.25.245.20:8081",
    "Connection": "keep-alive",
    "Referer": "http://120.25.245.20:8081/",
    "content-type": "application/json"
}

response = requests.request("POST", url, json=payload, headers=headers)

print(response.text)
```

**Node.js:**
```

const request = require('request');

const options = {
  method: 'POST',
  url: 'http://120.25.245.20:8092/OpenApi/Instruction',
  headers: {
    Authorization: 'eyJhbGciOiJIUzUxMiJ9.eyJsb2dpbl91c2VyX2tleSI6IjZjNTg4Yjk2LTkyNTQtNDcyMC1iYzMwLWQ0ZTI0Mzc4YzMyMCJ9.oTjYmJFpmPDSqFX8oHkzdBMYhidGWxDaeygdKY3SphFrxq3yRzyPOq80kFUW1CH-gVW8M6tRlzTrPkvANMQxMg',
    'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:121.0) Gecko/20100101 Firefox/121.0',
    Accept: 'application/json, text/plain, */*',
    'Accept-Language': 'zh-CN,zh;q=0.8,zh-TW;q=0.7,zh-HK;q=0.5,en-US;q=0.3,en;q=0.2',
    'Accept-Encoding': 'gzip, deflate',
    'Content-Type': 'application/json',
    Origin: 'http://120.25.245.20:8081',
    Connection: 'keep-alive',
    Referer: 'http://120.25.245.20:8081/',
    'content-type': 'application/json'
  },
  body: {
    FAction: 'ActivePhotograph',
    FAssetGUID: 'a64b2e58-9305-4a01-9c51-092205123945',
    FT_GpActivePhotograph: {FAssetID: '876208000137', FCount: 1},
    FTokenID: '3acef045-d302-4032-b40a-d9ee6c1519cd',
    FTimeDifferent: 28800,
    FLanguage: '1'
  },
  json: true
};

request(options, function (error, response, body) {
  if (error) throw new Error(error);

  console.log(body);
});

```