#### Brief Description:

- Query Asset Online Status

#### API Version:

| Version | Created by | Created Date | Revised Date |
| :------ | :--------- | :----------- | :----------- |
| 2.0.0   | lenny      | 2024-01-24   |              |

#### Request URL:

- International Client: http://icloud.assetscontrols.com:8092/OpenApi/Instruction
- Domestic Client: http://cloud.assetscontrols.com:8092/OpenApi/Instruction

#### Request Method:

- POST

#### Request Header:

| Parameter    | Required | Type   | Description                    |
| :----------- | :------- | :----- | ------------------------------ |
| Content-Type | Yes      | string | Request type: application/json |

#### Request Parameters:

| Parameter  | Required | Type   | Description                          |
| :--------- | :------- | :----- | ------------------------------------ |
| FTokenID   | Yes      | string | Token ID                             |
| FAction    | Yes      | string | Method name (QueryAssetOnlineStatus) |
| FAssetGUID | Yes      | string | Device unique identifier             |

#### Response Example:

**When successful:**

```
{
	"Result": 200,
	"Message": "check token success",
	"FObject": {
		"FAssetID": "876208000034",
		"FStatus": 3,
		"FGPSTime": "2023-10-07T07:40:26Z",
		"FRecvTime": "2023-10-07T07:40:31.631Z",
		"FLongitude": 0,
		"FLatitude": 0
	}
}
```

**When there's an error:**

```
{
    "Result": 102,
    "Message": "Action is error",
    "FObject": []
}
```

#### Response Parameters:

| Parameter  | Type   | Description                                      |
| :--------- | :----- | ------------------------------------------------ |
| FAssetID   | String | Device ID                                        |
| FStatus    | String | Status (0: Not activated, 1: Online, 3: Offline) |
| FGPSTime   | String | GPS time                                         |
| FRecvTime  | String | Receiving time                                   |
| FLongitude | Double | Longitude of the photo                           |
| FLatitude  | Double | Latitude of the photo                            |

#### Note:

- Additional error codes include:
- 105: System exception
- 102: Parameter error

#### Request Example:

**Java:**
```
String result = "";
String url = "http://cloud.assetscontrols.com:8092/OpenApi/Instruction";  
String body = "{\r\n    \"FAction\": \"QueryAssetOnlineStatus\",\r\n    \"FAssetGUID\": \"76e63f83-b869-4431-af27-a5dbecb5a49c\",\r\n    \"FTokenID\": \"3acef045-d302-4032-b40a-d9ee6c1519cd\",\r\n    \"FTimeDifferent\": 28800,\r\n    \"FLanguage\": \"1\"\r\n}";  
URL realUrl = new URL(url);
URLConnection conn = realUrl.openConnection(); 
conn.setRequestProperty("accept", "*/*");
conn.setRequestProperty("connection", "keep-Alive");
conn.setRequestProperty("Content-Type", "application/json");
conn.setRequestProperty("user-agent", "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1;SV1)");
conn.setRequestProperty("method", "post");
conn.setDoOutput(true);
conn.setDoInput(true);
PrintWriter pw = new PrintWriter(conn.getOutputStream());
pw.print(body);
pw.flush();   
BufferedReader bufReader = new BufferedReader(new InputStreamReader(conn.getInputStream()));  
String line;
while ((line = bufReader.readLine()) != null) {
     result += line;        
 }
return result;
```

**C#：**
```
string url = "http://cloud.assetscontrols.com:8092/OpenApi/Instruction";  
string body = "{\r\n    \"FAction\": \"QueryAssetOnlineStatus\",\r\n    \"FAssetGUID\": \"76e63f83-b869-4431-af27-a5dbecb5a49c\",\r\n    \"FTokenID\": \"3acef045-d302-4032-b40a-d9ee6c1519cd\",\r\n    \"FTimeDifferent\": 28800,\r\n    \"FLanguage\": \"1\"\r\n}"; 
Encoding encoding = Encoding.UTF8;
HttpWebRequest request = (HttpWebRequest)WebRequest.Create(url);
request.Method = "post"; 
request.Accept = "*/*";    
request.ContentType = "application/json";
request.UserAgent = "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)";
byte[] buffer = encoding.GetBytes(body);
request.ContentLength = buffer.Length;
request.GetRequestStream().Write(buffer, 0, buffer.Length);
HttpWebResponse response = (HttpWebResponse)request.GetResponse();
using (StreamReader reader = new StreamReader(response.GetResponseStream(), Encoding.UTF8))
{
    return reader.ReadToEnd();
}
```

**Python：**
```python
url = "http://cloud.assetscontrols.com:8092/OpenApi/Instruction"

payload = {
    "FAction": "QueryAssetOnlineStatus",
    "FAssetGUID": "76e63f83-b869-4431-af27-a5dbecb5a49c",
    "FTokenID": "3acef045-d302-4032-b40a-d9ee6c1519cd",
    "FTimeDifferent": 28800,
    "FLanguage": "1"

}
headers = {
    "Authorization": "eyJhbGciOiJIUzUxMiJ9.eyJsb2dpbl91c2VyX2tleSI6IjZjNTg4Yjk2LTkyNTQtNDcyMC1iYzMwLWQ0ZTI0Mzc4YzMyMCJ9.oTjYmJFpmPDSqFX8oHkzdBMYhidGWxDaeygdKY3SphFrxq3yRzyPOq80kFUW1CH-gVW8M6tRlzTrPkvANMQxMg",
    "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:121.0) Gecko/20100101 Firefox/121.0",
    "Accept": "application/json, text/plain, */*",
    "Accept-Language": "zh-CN,zh;q=0.8,zh-TW;q=0.7,zh-HK;q=0.5,en-US;q=0.3,en;q=0.2",
    "Accept-Encoding": "gzip, deflate",
    "Content-Type": "application/json",
    "Origin": "http://120.25.245.20:8081",
    "Connection": "keep-alive",
    "Referer": "http://120.25.245.20:8081/",
    "content-type": "application/json"
}

response = requests.request("POST", url, json=payload, headers=headers)

print(response.text)
```

**Node.js:**
```

const request = require('request');

const options = {
  method: 'POST',
  url: ' http://cloud.assetscontrols.com:8092/OpenApi/Instruction',
  headers: {
    Authorization: 'eyJhbGciOiJIUzUxMiJ9.eyJsb2dpbl91c2VyX2tleSI6IjZjNTg4Yjk2LTkyNTQtNDcyMC1iYzMwLWQ0ZTI0Mzc4YzMyMCJ9.oTjYmJFpmPDSqFX8oHkzdBMYhidGWxDaeygdKY3SphFrxq3yRzyPOq80kFUW1CH-gVW8M6tRlzTrPkvANMQxMg',
    'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:121.0) Gecko/20100101 Firefox/121.0',
    Accept: 'application/json, text/plain, */*',
    'Accept-Language': 'zh-CN,zh;q=0.8,zh-TW;q=0.7,zh-HK;q=0.5,en-US;q=0.3,en;q=0.2',
    'Accept-Encoding': 'gzip, deflate',
    'Content-Type': 'application/json',
    Origin: 'http://120.25.245.20:8081',
    Connection: 'keep-alive',
    Referer: 'http://120.25.245.20:8081/',
    'content-type': 'application/json'
  },
 body: {
    FAction: 'QueryAssetOnlineStatus',
    FAssetGUID: '76e63f83-b869-4431-af27-a5dbecb5a49c',
    FTokenID: '3acef045-d302-4032-b40a-d9ee6c1519cd',
    FTimeDifferent: 28800,
    FLanguage: '1'
  },
  json: true
};

request(options, function (error, response, body) {
  if (error) throw new Error(error);

  console.log(body);
});

```