#### Brief description:

- Get basic information of the device

#### API version:

| Version number | Creator | Creation date | Revision date |
| :------------- | :------ | :------------ | ------------- |
| 2.0.0          | Lenny   | 2020-06-20    | 2020-06-20    |

#### Request URL:

- http://icloud.assetscontrols.com:8092/OpenApi/Admin
- https://icloud.assetscontrols.com:3443/OpenApi/Admin

#### Request method:

- POST

#### Request header:

| Parameter name | Required | Type   | Description                    |
| :------------- | :------- | :----- | ------------------------------ |
| Content-Type   | Yes      | string | Request type: application/json |

#### Request parameters:

| Parameter name | Required | Type   | Description                       |
| :------------- | :------- | :----- | --------------------------------- |
| FTokenID       | Yes      | string | Token ID                          |
| FAction        | Yes      | string | Method Name (QueryAdminAssetList) |

#### Example Response:

**Success:**

```
{
    "Result": 200,
    "Message": "check token success",
    "FObject": [
        {
            "FGUID": "10f47be0-fefc-4cc2-ae69-50a14bbfa55c",
            "FAssetID": "7560717002",
            "FAssetTypeID": 701,
            "FDescription": "",
            "FSIMNumber": "343343434",
            "FAgentGUID": "25a48ca5-a844-4732-8af4-afa2a9d5c6dc",
            "FAgentName": "测试",
            "FGroupGUID": null,
            "FGroupName": null,
            "FCreateTime": "2020-05-17T12:10:44.143"
        },
        {
            "FGUID": "983809d8-a894-43f8-8b52-37bab146fb13",
            "FAssetID": "868120231481844",
            "FAssetTypeID": 1010,
            "FDescription": "",
            "FSIMNumber": "868120231481844",
            "FAgentGUID": "4bfca45f-807d-45f4-bf4c-4ebabbf857ca",
            "FAgentName": "Concox测试",
            "FGroupGUID": null,
            "FGroupName": null,
            "FCreateTime": "2020-07-31T02:30:37.433"
        }
    ]
}
```

**Error:**

```
{
    "Result": 102,
    "Message": "Action is error",
    "FObject": []
}
```

#### Return parameter description:

| Parameter Name | Type     | Description                                                  |
| :------------- | :------- | ------------------------------------------------------------ |
| FGUID          | String   | Device unique identifier                                     |
| FAssetID       | String   | Device ID                                                    |
| FAssetTypeID   | Int      | Device type                                                  |
| FDescription   | String   | Device description                                           |
| FSIMNumber     | String   | SIM card number                                              |
| FAgentGUID     | String   | Unique identifier of the company to which the device belongs |
| FAgentName     | String   | Name of the company to which the device belongs              |
| FGroupGUID     | String   | Unique identifier of the group to which the device belongs   |
| FGroupName     | String   | Name of the group to which the device belongs                |
| FCreateTime    | DateTime | Registration time (UTC time)                                 |
| FExpireTime    | DateTime | Device expiration time (UTC time)                            |

#### Note:

- More error codes are as follows:
- 104: Token error or expired
- 105: System exception
- 102: Request parameter error

#### Request Example:

**Java:**

```
String result = "";
// Request URL
String url = "http://cloud.assetscontrols.com:8092/OpenApi/Admin";  
// Request parameters, in JSON format, it is recommended to use objects to pass in
String body = "{FAction:\"QueryAdminAssetList\",FTokenID:\"3acef045-d302-4032-b40a-d9ee6c1519cd\"}";  
URL realUrl = new URL(url);
// Set the properties of the common request
URLConnection conn = realUrl.openConnection(); 
conn.setRequestProperty("accept", "*/*");
conn.setRequestProperty("connection", "keep-Alive");
conn.setRequestProperty("Content-Type", "application/json");
conn.setRequestProperty("user-agent", "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1;SV1)");
conn.setRequestProperty("method", "post");
// Must set the following two lines for sending POST requests
conn.setDoOutput(true);
conn.setDoInput(true);
PrintWriter pw = new PrintWriter(conn.getOutputStream());
// Send request parameters
pw.print(body);
// Flush the output stream buffer  
pw.flush();   
// Define a BufferedReader input stream to read the URL response
BufferedReader bufReader = new BufferedReader(new InputStreamReader(conn.getInputStream()));  
// Define a BufferedReader input stream to read the URL response
String line;
while ((line = bufReader.readLine()) != null) {
     result += line;        
 }
// The returned result is a JSON string
return result;
```

**C#:**

```
// Request URL
string url = "http://cloud.assetscontrols.com:8092/OpenApi/Admin";  
// Request parameters, in JSON format, it is recommended to use objects to pass in
string body = "{FAction:\"QueryAdminAssetList\",FTokenID:\"3acef045-d302-4032-b40a-d9ee6c1519cd\"}"; 
Encoding encoding = Encoding.UTF8;
HttpWebRequest request = (HttpWebRequest)WebRequest.Create(url);
 // Request method: post / get
request.Method = "post"; 
request.Accept = "*/*";    
request.ContentType = "application/json";
request.UserAgent = "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)";
byte[] buffer = encoding.GetBytes(body);
request.ContentLength = buffer.Length;
request.GetRequestStream().Write(buffer, 0, buffer.Length);
HttpWebResponse response = (HttpWebResponse)request.GetResponse();
using (StreamReader reader = new StreamReader(response.GetResponseStream(), Encoding.UTF8))
{
	// The returned result is a JSON string
    return reader.ReadToEnd();
}
```

**Python:**

```
url = 'http://cloud.assetscontrols.com:8092/OpenApi/Admin'
      data = {
      'FAction': 'QueryAdminAssetList',
      'FTokenID': '3acef045-d302-4032-b40a-d9ee6c1519cd'
       }
      data = parse.urlencode(data).encode('utf-8')
      headers = {
       'User-Agent': r'Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) '
                     r'Chrome/45.0.2454.85 Safari/537.36 115Browser/6.0.3',
       'Connection': 'keep-alive'
       }
      req = request.Request(url, headers=headers, data=data)  
      page = request.urlopen(req).read()
      page = page.decode('utf-8')
      # json_array = json.loads(page)
      return page;
```