#### Brief description:

- Get all asset types

#### API Version：

| Version Number | Developer | Date of Formulation | Date of Revision |
| :------------- | :-------- | :------------------ | ---------------- |
| 2.0.0          | lenny     | 2023-04-07          |                  |

#### Request URL:

- http://icloud.assetscontrols.com:8092/OpenApi/Admin
- https://icloud.assetscontrols.com:3443/OpenApi/Admin

#### Request Method:

- POST

#### Request Header:

| Parameter Name | Required | Type   | Description                     |
| :------------- | :------- | :----- | ------------------------------- |
| Content-Type   | Yes      | string | Request Type： application/json |

#### Request Parameters:

| Parameter Name | Required | Type   | Description                         |
| :------------- | :------- | :----- | ----------------------------------- |
| FTokenID       | Yes      | string | Token ID                            |
| FAction        | Yes      | string | Method name (QueryAdminVehicleType) |
| FGUID          | Yes      | string | Vehicle unique identifier           |

#### Return Example:

**Returned correctly:**

```
{
    "Result": 200,
    "Message": "check token success",
    "FObject": [
        {
            "FVehicleTypeID": 1,
            "FVehicleTypeName": "货车",
            "FEnTypeName": "Truck"
        },
        {
            "FVehicleTypeID": 2,
            "FVehicleTypeName": "小型客车",
            "FEnTypeName": "Minibus"
        },
        {
            "FVehicleTypeID": 3,
            "FVehicleTypeName": "出租车",
            "FEnTypeName": "Taxi"
        },
        {
            "FVehicleTypeID": 4,
            "FVehicleTypeName": "大型客车",
            "FEnTypeName": "Bus"
        },
        {
            "FVehicleTypeID": 5,
            "FVehicleTypeName": "集装箱",
            "FEnTypeName": "Container"
        },
        {
            "FVehicleTypeID": 6,
            "FVehicleTypeName": "冷箱车",
            "FEnTypeName": "Truck-R"
        },
        {
            "FVehicleTypeID": 7,
            "FVehicleTypeName": "厢式货车",
            "FEnTypeName": "VAN"
        },
        {
            "FVehicleTypeID": 8,
            "FVehicleTypeName": "拖车",
            "FEnTypeName": "Trailer"
        },
        {
            "FVehicleTypeID": 9,
            "FVehicleTypeName": "小汽车",
            "FEnTypeName": "Car"
        },
        {
            "FVehicleTypeID": 10,
            "FVehicleTypeName": "摩托车",
            "FEnTypeName": "Motorcycle"
        },
        {
            "FVehicleTypeID": 11,
            "FVehicleTypeName": "冷库",
            "FEnTypeName": "Cold Store"
        }
    ]
}
```

**Returned incorrectly:**

```
{
    "Result": 102,
    "Message": "Action is error",
    "FObject": []
}
```

#### Return Parameters Description:

| Parameter Name   | Type   | Description                 |
| :--------------- | :----- | --------------------------- |
| FEnTypeName      | String | Vehicle type name (English) |
| FVehicleTypeName | String | Vehicle type name (Chinese) |
| FVehicleTypeID   | Int    | Vehicle type                |

#### Remarks:

- More return error codes are as follows:
- 104: Token error or expiration
- 105: System exception
- 102: Request parameter error

#### Request Example:

**Java:**

```
String result = "";
//request url
String url = "http://cloud.assetscontrols.com:8092/OpenApi/Admin";  
//request body, json format, it's recommended to use an object to pass in the parameters
String body = "{FAction:\"QueryAdminVehicleType\",FTokenID:\"3acef045-d302-4032-b40a-d9ee6c1519cd\"}";  
URL realUrl = new URL(url);
// set general request properties
URLConnection conn = realUrl.openConnection(); 
conn.setRequestProperty("accept", "*/*");
conn.setRequestProperty("connection", "keep-Alive");
conn.setRequestProperty("Content-Type", "application/json");
conn.setRequestProperty("user-agent", "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1;SV1)");
conn.setRequestProperty("method", "post");
// send POST request, must set these two lines of code
conn.setDoOutput(true);
conn.setDoInput(true);
PrintWriter pw = new PrintWriter(conn.getOutputStream());
// send request parameters
pw.print(body);
// flush output stream buffer
pw.flush();   
// define a BufferedReader object to read the response from the url
BufferedReader bufReader = new BufferedReader(new InputStreamReader(conn.getInputStream()));  
// read the response line by line
String line;
while ((line = bufReader.readLine()) != null) {
     result += line;        
 }
// the returned string is in json format
return result;
```

**C#：**

```
//request url
string url = "http://cloud.assetscontrols.com:8092/OpenApi/Admin";  
//request body, json format, it's recommended to use an object to pass in the parameters
string body = "{FAction:\"QueryAdminVehicleType\",FTokenID:\"3acef045-d302-4032-b40a-d9ee6c1519cd\"}"; 
Encoding encoding = Encoding.UTF8;
HttpWebRequest request = (HttpWebRequest)WebRequest.Create(url);
 //request method: post or get
request.Method = "post"; 
request.Accept = "*/*";    
request.ContentType = "application/json";
request.UserAgent = "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)";
byte[] buffer = encoding.GetBytes(body);
request.ContentLength = buffer.Length;
request.GetRequestStream().Write(buffer, 0, buffer.Length);
HttpWebResponse response = (HttpWebResponse)request.GetResponse();
using (StreamReader reader = new StreamReader(response.GetResponseStream(), Encoding.UTF8))
{
	// the returned string is in json format
    return reader.ReadToEnd();
}
```

**Python：**

```
url = 'http://cloud.assetscontrols.com:8092/OpenApi/Admin'
      data = {
      'FAction': 'QueryAdminVehicleType',
      'FTokenID': '3acef045-d302-4032-b40a-d9ee6c1519cd'
       }
      data = parse.urlencode(data).encode('utf-8')
      headers = {
       'User-Agent': r'Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) '
                     r'Chrome/45.0.2454.85 Safari/537.36 115Browser/6.0.3',
       'Connection': 'keep-alive'
       }
      req = request.Request(url, headers=headers, data=data)  
      page = request.urlopen(req).read()
      page = page.decode('utf-8')
      # the returned string is in json format
      return page;
```