#### Brief description:

- Get basic information of a asset

#### API version:

| Version number | Made by | Date of formulation | Date of revision |
| :------------- | :------ | :------------------ | ---------------- |
| 2.0.0          | lenny   | 2020-06-20          | 2020-06-20       |

#### Request URL:

- http://icloud.assetscontrols.com:8092/OpenApi/Admin
- https://icloud.assetscontrols.com:3443/OpenApi/Admin

#### Request method:

- POST

#### Request header:

| Parameter Name | Mandatory | Type   | Description                    |
| :------------- | :-------- | :----- | ------------------------------ |
| Content-Type   | Yes       | string | Request type: application/json |

#### Request parameters:

| Parameter Name | Mandatory | Type   | Description                         |
| :------------- | :-------- | :----- | ----------------------------------- |
| FTokenID       | Yes       | string | Token ID                            |
| FAction        | Yes       | string | Method name (QueryAdminVehicleList) |

#### Example Response:

**Success:**

```
{
    "Result": 200,
    "Message": "check token success",
    "FObject": [
        {
            "FGUID": "4b0be13f-4703-4629-93d2-b51f632344dc",
            "FVehicleName": "视频机816",
            "FAssetGUID": "066cd9b2-b64b-44f5-9f19-b6e7dc974140",
            "FAssetID": "6165016816",
            "FAssetTypeID": 808,
            "FVehicleCode": "816",
            "FVehicleTypeID": 1,
            "FDescription": "",
            "FOperateType": "",
            "FVIN": "",
            "FAgentGUID": "903ba776-b329-474e-86b1-3a922c54f821",
            "FAgentName": "部标测试",
            "FGroupGUID": "0b887ae3-e190-42a2-81f3-81f6127c8aa1",
            "FGroupName": "视频机测试",
            "FMainDriverGUID": "778572c1-7ca4-44a9-ab2d-6c4f9cfed800",
            "FDriverName": "Jhon",
            "FDriverPhoneNumber": "18362985485",
            "FCreateTime": "2020-07-20T06:13:37.613"
        },
        {
            "FGUID": "9154a616-038e-40da-91b4-87b7faccc15f",
            "FVehicleName": "粤B45678",
            "FAssetGUID": null,
            "FAssetID": null,
            "FAssetTypeID": null,
            "FVehicleCode": "",
            "FVehicleTypeID": 1,
            "FDescription": "粤B45678",
            "FOperateType": "1",
            "FVIN": "",
            "FAgentGUID": "4b3dd67a-00af-4118-87bf-fa9583a83b25",
            "FAgentName": "Joint测试",
            "FGroupGUID": "b595f14b-e8a7-49b3-b26c-4687ebfcb33f",
            "FGroupName": "JT702/JT705",
            "FMainDriverGUID": "00000000-0000-0000-0000-000000000000",
            "FDriverName": null,
            "FDriverPhoneNumber": null,
            "FCreateTime": "2020-08-04T09:27:21.127"
        }
      }
   ]
}
```

**Error:**

```
{
    "Result": 102,
    "Message": "Action is error",
    "FObject": []
}
```

#### Response Parameters:

| Parameter Name     | Type     | Description                                                  |
| :----------------- | :------- | ------------------------------------------------------------ |
| FGUID              | String   | Vehicle unique identifier                                    |
| FVehicleName       | String   | Vehicle name                                                 |
| FAssetGUID         | String   | Equipment unique identifier                                  |
| FAssetID           | String   | Equipment ID                                                 |
| FAssetTypeID       | Int      | Equipment type                                               |
| FVehicleCode       | String   | Vehicle code                                                 |
| FVehicleTypeID     | Int      | Vehicle type                                                 |
| FDescription       | String   | Description                                                  |
| FOperateType       | String   | Operation type (1: self-support; 2: leasing)                 |
| FVIN               | String   | Vehicle identification number                                |
| FAgentGUID         | String   | Unique identifier of the company to which the equipment belongs |
| FAgentName         | String   | Name of the company to which the equipment belongs           |
| FGroupGUID         | String   | Unique identifier of the group to which the equipment belongs |
| FGroupName         | String   | Name of the group to which the equipment belongs             |
| FMainDriverGUID    | String   | Unique identifier of the main driver                         |
| FDriverName        | String   | Name of the main driver                                      |
| FDriverPhoneNumber | String   | Phone number of the main driver                              |
| FCreateTime        | DateTime | Registration time (UTC time)                                 |

#### Remarks:

- More error codes are as follows:
- 104: Token error or expired
- 105: System exception
- 102: Request parameter error

#### Request Example:

**Java:**

```
String result = "";
// Request URL
String url = "http://cloud.assetscontrols.com:8092/OpenApi/Admin";  
// Request parameter, in json format, it is recommended to pass in as an object
String body = "{FAction:\"QueryAdminVehicleList\",FTokenID:\"3acef045-d302-4032-b40a-d9ee6c1519cd\"}";  
URL realUrl = new URL(url);
// Set the general request properties
URLConnection conn = realUrl.openConnection(); 
conn.setRequestProperty("accept", "*/*");
conn.setRequestProperty("connection", "keep-Alive");
conn.setRequestProperty("Content-Type", "application/json");
conn.setRequestProperty("user-agent", "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1;SV1)");
conn.setRequestProperty("method", "post");
// Sending a POST request requires setting the following two lines
conn.setDoOutput(true);
conn.setDoInput(true);
PrintWriter pw = new PrintWriter(conn.getOutputStream());
// Sending request parameters
pw.print(body);
// Flush the output stream buffer
pw.flush();   
// Define a BufferedReader input stream to read the URL response
BufferedReader bufReader = new BufferedReader(new InputStreamReader(conn.getInputStream()));  
// Read the URL response using the BufferedReader input stream
String line;
while ((line = bufReader.readLine()) != null) {
     result += line;        
 }
// The returned value is a JSON string
return result;
```

**C#：**

```
// Request URL
string url = "http://cloud.assetscontrols.com:8092/OpenApi/Admin";  
// Request parameter, in json format, it is recommended to pass in as an object
string body = "{FAction:\"QueryAdminVehicleList\",FTokenID:\"3acef045-d302-4032-b40a-d9ee6c1519cd\"}"; 
Encoding encoding = Encoding.UTF8;
HttpWebRequest request = (HttpWebRequest)WebRequest.Create(url);
// Request method post / get
request.Method = "post"; 
request.Accept = "*/*";    
request.ContentType = "application/json";
request.UserAgent = "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)";
byte[] buffer = encoding.GetBytes(body);
request.ContentLength = buffer.Length;
request.GetRequestStream().Write(buffer, 0, buffer.Length);
HttpWebResponse response = (HttpWebResponse)request.GetResponse();
using (StreamReader reader = new StreamReader(response.GetResponseStream(), Encoding.UTF8))
{
	// The returned value is a JSON string
    return reader.ReadToEnd();
}
```

**Python:**

```
import urllib
from urllib import request, parse

url = 'http://cloud.assetscontrols.com:8092/OpenApi/Admin'
data = {
    'FAction': 'QueryAdminVehicleList',
    'FTokenID': '3acef045-d302-4032-b40a-d9ee6c1519cd'
}
data = parse.urlencode(data).encode('utf-8')
headers = {
    'User-Agent': r'Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) '
                  r'Chrome/45.0.2454.85 Safari/537.36 115Browser/6.0.3',
    'Connection': 'keep-alive'
}
req = request.Request(url, headers=headers, data=data)  
page = request.urlopen(req).read()
page = page.decode('utf-8')
# json_array = json.loads(page)
return page;
```