#### Brief Description:

- Query all fence and fence group information under the company

#### API Version:

| Version | Author | Date Created | Date Updated |
| :------ | :----- | :----------- | ------------ |
| 1.0.0   | lenny  | 2022-09-22   | 2020-09-22   |

#### Request URL:

- http://icloud.assetscontrols.com:8092/OpenApi/Admin
- https://icloud.assetscontrols.com:3443/OpenApi/Admin

#### Method:

- POST

#### Request Headers:

| Parameter    | Required | Type   | Description                    |
| :----------- | :------- | :----- | ------------------------------ |
| Content-Type | Yes      | string | Request Type: application/json |

#### Request Parameters:

| Parameter  | Required | Type   | Description                    |
| :--------- | :------- | :----- | ------------------------------ |
| FTokenID   | Yes      | string | Token ID                       |
| FAction    | Yes      | string | Method name (AddGISFenceBatch) |
| FAgentGUID | Yes      | string | Company unique identifier      |

#### Response Example:

**Successful Response:**

```
{
    "Result": 200,
    "Message":"success",
    "FObject": [		{
			"FGUID": "ed86c973-07e3-4f0a-afed-00ad8c176db5",
			"FName": "GuanTian subway station",
			"FNumber": "04",
			"FRemark": "test",
			"FArea": 87313.54065700735,
			"FFormType": 1,
			"FFenceTypeGUID": "df0f8ab2-742e-448b-9c5e-088f88e996d5",
			"FPath": "[{\"lat\":22.68714446,\"lng\":113.94369331},{\"lat\":22.68683927,\"lng\":113.94710827},{\"lat\":22.68504754,\"lng\":113.94646312},{\"lat\":22.68561273,\"lng\":113.94355122},{\"lat\":22.6858369,\"lng\":113.94067669}]",
			"FRadius": 0,
			"FCenterLon": 113.94450032,
			"FCenterLat": 22.68618174,
			"FAddress": "47 meters near 18 XinYongFeng GuanTian Industrial Zone, North Ring Road, Bao'an District, Shenzhen, Guangdong Province",
			"FCreateTime": "2023-02-23T02:42:04.87",
			"FAgentGUID": "661e7209-c77e-4a54-afb8-6d956f962bdf",
			"FAgentName": "Software Test Department",
			"FFenceTypeName": "Transportation Route"
		}]
}
```

**Error Response:**

```
// Indicates that the unique identifier of the company passed in is null, which should be due to incorrect data format
{
    "Result": 102,
    "Message": "FAgentGUID is null",
    "FObject": []
}
// Indicates that there is an exception error
{
    "Result": 105,
    "Message": "fail",
    "FObject": []
}
```

#### Response Parameter Description:

| Parameter Name | Type   | Description                          |
| :------------- | :----- | :----------------------------------- |
| FGUID          | string | Unique identifier of the fence       |
| FName          | string | Name of the fence                    |
| FNumber        | string | Fence number                         |
| FRemark        | string | Remarks                              |
| FArea          | string | Area                                 |
| FFormType      | int    | Type (1: polygon; 2: circle)         |
| FFenceTypeGUID | string | Unique identifier of the fence group |
| FPath          | string | Point set                            |
| FRadius        | int    | Radius                               |
| FCenterLon     | double | Longitude of the center point        |
| FCenterLat     | double | Latitude of the center point         |
| FAddress       | string | Address                              |
| FCreateTime    | string | Creation time                        |
| FAgentGUID     | string | Unique identifier of the company     |
| FAgentName     | string | Company name                         |
| FFenceTypeName | string | Name of the fence group              |

#### Note:

- More error codes are as follows:
- 102: Request parameter error
- 104: Token expired
- 105: Indicates that there is an exception error

#### Request Example:

**Java:**

```
String result = "";
// Request URL
String url = "http://cloud.assetscontrols.com:8092/OpenApi/Admin";
// Request parameters, in JSON format, recommend to use an object to pass in
String body = "{
	\"FAction\": \"QueryGISFenceByFAgentGUID\",
	\"FAgentGUID\": \"661e7209-c77e-4a54-afb8-6d956f962bdf\",
	\"FTokenID\": \"ec51d691-d9a7-4f74-95a8-1856be2ae745\",
	\"FTimeDifferent\": 28800,
	\"FLanguage\": \"1\"
}";
URL realUrl = new URL(url);
// Set generic properties of the request
URLConnection conn = realUrl.openConnection();
conn.setRequestProperty("accept", "*/*");
conn.setRequestProperty("connection", "keep-Alive");
conn.setRequestProperty("Content-Type", "application/json");
conn.setRequestProperty("user-agent", "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1;SV1)");
conn.setRequestProperty("method", "post");
// Must set the following two lines when sending a POST request
conn.setDoOutput(true);
conn.setDoInput(true);
PrintWriter pw = new PrintWriter(conn.getOutputStream());
// Send request parameters
pw.print(body);
// flush the output stream buffer
pw.flush();
// Define BufferedReader input stream to read the URL response
BufferedReader bufReader = new BufferedReader(new InputStreamReader(conn.getInputStream()));
// Define BufferedReader input stream to read the URL response
String line;
while ((line = bufReader.readLine()) != null) {
    result += line;
}
// The returned value is in JSON format
return result;
```

**C#:**

```
// Request URL
string url = "http://cloud.assetscontrols.com:8092/OpenApi/Admin";
// Request parameters, in JSON format, recommend to use an object to pass in
string body = "{
	\"FAction\": \"QueryGISFenceByFAgentGUID\",
	\"FAgentGUID\": \"661e7209-c77e-4a54-afb8-6d956f962bdf\",
	\"FTokenID\": \"ec51d691-d9a7-4f74-95a8-1856be2ae745\",
	\"FTimeDifferent\": 28800,
	\"FLanguage\": \"1\"
}";
Encoding encoding = Encoding.UTF8;
HttpWebRequest request = (HttpWebRequest)WebRequest.Create(url);
// Request method: post / get
request.Method = "post"; 
request.Accept = "*/*";    
request.ContentType = "application/json";
request.UserAgent = "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)";
byte[] buffer = encoding.GetBytes(body);
request.ContentLength = buffer.Length;
request.GetRequestStream().Write(buffer, 0, buffer.Length);
HttpWebResponse response = (HttpWebResponse)request.GetResponse();
using (StreamReader reader = new StreamReader(response.GetResponseStream(), Encoding.UTF8))
{
	// The returned value is in JSON format
    return reader.ReadToEnd();
}
```

**Python:**

```
import urllib.parse as parse
from urllib import request

url = 'http://cloud.assetscontrols.com:8092/OpenApi/Admin'
data = {
    'FAction': 'QueryGISFenceByFAgentGUID',
    'FAgentGUID': '661e7209-c77e-4a54-afb8-6d956f962bdf',
    'FTokenID': 'ec51d691-d9a7-4f74-95a8-1856be2ae745',
    'FTimeDifferent': 28800,
    'FLanguage': '1'
}
data = parse.urlencode(data).encode('utf-8')
headers = {
    'User-Agent': r'Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) '
                  r'Chrome/45.0.2454.85 Safari/537.36 115Browser/6.0.3',
    'Connection': 'keep-alive'
}
req = request.Request(url, headers=headers, data=data)
page = request.urlopen(req).read()
page = page.decode('utf-8')
# The returned value is in JSON format
return page;
```