#### Description：

- Bind vehicles to fences

#### API Version：

| Version | Author | Date of Creation | Date of Revision |
| :------ | :----- | :--------------- | ---------------- |
| 1.0.0   | lenny  | 2022-09-22       | 2020-09-22       |

#### Request URL:

- http://icloud.assetscontrols.com:8092/OpenApi/GISServer
- https://icloud.assetscontrols.com:3443/OpenApi/GISServer

#### Request Method:

- POST

#### Request Headers:

| Parameter    | Required | Type   | Description                    |
| :----------- | :------- | :----- | ------------------------------ |
| Content-Type | Yes      | string | Request type: application/json |

#### Request Parameters:

| Parameter              | Required | Type                   | Description                    |
| :--------------------- | :------- | :--------------------- | ------------------------------ |
| FTokenID               | Yes      | string                 | Token ID                       |
| FAction                | Yes      | string                 | Method name (UpdateGISVihicleBindFence) |
| FT_GISVihicleBindFence | Yes      | FT_GISVihicleBindFence | Vehicle fence information list |

##### FT_GISVihicleBindFence Object Description:

| Parameter       | Required | Type   | Description                                                  |
| :-------------- | :------- | :----- | ------------------------------------------------------------ |
| FVehicleGUID    | Yes      | string | Vehicle unique identifier                                    |
| FFenceGUID      | Yes      | string | Fence unique identifier                                      |
| FInAlarm        | No       | int    | In-fence alarm                                               |
| FOutAlarm       | No       | int    | Out-of-fence alarm                                           |
| FStopAlarm      | No       | int    | In-fence timeout-stop alarm                                  |
| FStopTime       | No       | int    | In-fence stop-time threshold                                 |
| FOutUnLockAlarm | No       | int    | Out-of-fence unlock alarm                                    |
| FUnLockFence    | No       | int    | In-fence unlocking (can only be unlocked in specific fences after being enabled) |

#### Response Example:

**When successful:**

```
xmlCopy Code{
    "Result": 200,
    "Message":"success",
    "FObject": []
}
```

**When error occurs:**

```
xmlCopy Code//Indicates that the passed object is empty, which should be due to incorrect data format.
{
    "Result": 102,
    "Message": "FT_GISFenceList is null",
    "FObject": []
}
//Indicates that an exception occurred.
{
    "Result": 105,
    "Message": "fail",
    "FObject": []
}
```

#### Remarks:

- More error codes for return are as follows:
- 102: Request parameter error
- 104: Token expired
- 105: Indicates that an exception occurred.

#### Request Example:

**Java:**

```
Copy CodeString result = "";
// Request URL
String url = "http://cloud.assetscontrols.com:8092/OpenApi/Admin";  
// Request body, recommended to use an object to pass parameters in JSON format
String body = "{\r\n  \"FAction\": \"UpdateGISVihicleBindFence\",\r\n  \"FT_GISVihicleBindFence\": {\r\n    \"FVehicleGUID\": \"36f13b9b-62f9-4de2-aa82-9c065cb97027\",\r\n    \"FFenceGUID\": \"32f30c76-a7ac-4f68-b384-230e1ac471c9,655179b6-0cd4-46d9-a8cc-5f8b793fedd4,46e70dbf-8e6b-431d-84c7-7f1eac1cb603,6db5a322-b1c9-4fc0-b5eb-c962b0d8d610,fbdb37c1-bc4b-4433-8110-e1eb9bea8f5e\",\r\n    \"FInAlarm\": 0,\r\n    \"FOutAlarm\": 0,\r\n    \"FStopAlarm\": 0,\r\n    \"FStopTime\": 0,\r\n    \"FOverspeedAlarm\": 0,\r\n    \"FOverspeedValue\": 0,\r\n    \"FOutUnLockAlarm\": 0,\r\n    \"FUnLockFence\": 1,\r\n    \"FOffline\": 0,\r\n  },\r\n  \"FTokenID\": \"ec51d691-d9a7-4f74-95a8-1856be2ae745\",\r\n  \"FTimeDifferent\": 28800,\r\n  \"FLanguage\": \"1\"\r\n}";
URL realUrl = new URL(url);
// Set common request properties
URLConnection conn = realUrl.openConnection(); 
conn.setRequestProperty("accept", "*/*");
conn.setRequestProperty("connection", "keep-Alive");
conn.setRequestProperty("Content-Type", "application/json");
conn.setRequestProperty("user-agent", "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1;SV1)");
conn.setRequestProperty("method", "post");
// Must set the following two lines for sending a POST request
conn.setDoOutput(true);
conn.setDoInput(true);
PrintWriter pw = new PrintWriter(conn.getOutputStream());
// Send request parameters
pw.print(body);
// Flush the output stream's buffer  
pw.flush();   
// Define BufferedReader to read the response from the URL
BufferedReader bufReader = new BufferedReader(new InputStreamReader(conn.getInputStream()));  
// Read the response from the URL
String line;
while ((line = bufReader.readLine()) != null) {
     result += line;        
 }
// The return value is a JSON string
return result;
```

**C#:**

```
Copy Code// Request URL
string url = "http://cloud.assetscontrols.com:8092/OpenApi/Admin";  
// Request body, recommended to use an object to pass parameters in JSON format
string body =  "{\r\n  \"FAction\": \"UpdateGISVihicleBindFence\",\r\n  \"FT_GISVihicleBindFence\": {\r\n    \"FVehicleGUID\": \"36f13b9b-62f9-4de2-aa82-9c065cb97027\",\r\n    \"FFenceGUID\": \"32f30c76-a7ac-4f68-b384-230e1ac471c9,655179b6-0cd4-46d9-a8cc-5f8b793fedd4,46e70dbf-8e6b-431d-84c7-7f1eac1cb603,6db5a322-b1c9-4fc0-b5eb-c962b0d8d610,fbdb37c1-bc4b-4433-8110-e1eb9bea8f5e\",\r\n    \"FInAlarm\": 0,\r\n    \"FOutAlarm\": 0,\r\n    \"FStopAlarm\": 0,\r\n    \"FStopTime\": 0,\r\n    \"FOverspeedAlarm\": 0,\r\n    \"FOverspeedValue\": 0,\r\n    \"FOutUnLockAlarm\": 0,\r\n    \"FUnLockFence\": 1,\r\n    \"FOffline\": 0,\r\n  },\r\n  \"FTokenID\": \"ec51d691-d9a7-4f74-95a8-1856be2ae745\",\r\n  \"FTimeDifferent\": 28800,\r\n  \"FLanguage\": \"1\"\r\n}";
Encoding encoding = Encoding.UTF8;
HttpWebRequest request = (HttpWebRequest)WebRequest.Create(url);
 // Request method: post / get
request.Method = "post"; 
request.Accept = "*/*";    
request.ContentType = "application/json";
request.UserAgent = "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)";
byte[] buffer = encoding.GetBytes(body);
request.ContentLength = buffer.Length;
request.GetRequestStream().Write(buffer, 0, buffer.Length);
HttpWebResponse response = (HttpWebResponse)request.GetResponse();
using (StreamReader reader = new StreamReader(response.GetResponseStream(), Encoding.UTF8))
{
	// The return value is a JSON string
    return reader.ReadToEnd();
}
```

**Python:**

```
pythonCopy Codeimport urllib.request as request
import urllib.parse as parse

url = 'http://cloud.assetscontrols.com:8092/OpenApi/Admin'
data =  '{ "FAction": "UpdateGISVihicleBindFence", "FT_GISVihicleBindFence": { "FVehicleGUID": "36f13b9b-62f9-4de2-aa82-9c065cb97027", "FFenceGUID": "32f30c76-a7ac-4f68-b384-230e1ac471c9,655179b6-0cd4-46d9-a8cc-5f8b793fedd4,46e70dbf-8e6b-431d-84c7-7f1eac1cb603,6db5a322-b1c9-4fc0-b5eb-c962b0d8d610,fbdb37c1-bc4b-4433-8110-e1eb9bea8f5e", "FInAlarm": 0, "FOutAlarm": 0, "FStopAlarm": 0, "FStopTime": 0, "FOverspeedAlarm": 0, "FOverspeedValue": 0, "FOutUnLockAlarm": 0, "FUnLockFence": 1, "FOffline": 0, }, "FTokenID": "ec51d691-d9a7-4f74-95a8-1856be2ae745", "FTimeDifferent": 28800, "FLanguage": "1" }'
data = parse.urlencode(data).encode('utf-8')
headers = {
       'User-Agent': r'Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) '
                     r'Chrome/45.0.2454.85 Safari/537.36 115Browser/6.0.3',
       'Connection': 'keep-alive'
       }
 req = request.Request(url, headers=headers, data=data)  
 page = request.urlopen(req).read()
 page = page.decode('utf-8')
 # The return value is a JSON string
 return page;
```